Contributing
============

We welcome large or small contributions to :code:`GWPopulation`.
We follow a standard fork and pull request workflow for contributions.
If you're unfamiliar, you can find a guide `here <https://guides.github.com/activities/forking/>`_.

.. toctree::
    :maxdepth: 1

    scope
    style
    testing
    code_of_conduct
    faq
